@@ -1,8 +1,11 @@
 package Locale::POFileManager::File;
-{
-  $Locale::POFileManager::File::VERSION = '0.04';
+BEGIN {
+  $Locale::POFileManager::File::AUTHORITY = 'cpan:DOY';
 }
-use Moose;
+{
+  $Locale::POFileManager::File::VERSION = '0.05';
+}
+use Moose 0.90;
 # ABSTRACT: A single .po file
 
 use MooseX::Types::Path::Class qw(File);
@@ -145,6 +148,7 @@ no Moose;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -153,7 +157,7 @@ Locale::POFileManager::File - A single .po file
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -256,10 +260,9 @@ Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2013 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
